diff options
| author | ReinUsesLisp <reinuseslisp@airmail.cc> | 2021-06-16 21:14:57 -0300 |
|---|---|---|
| committer | ameerj <52414509+ameerj@users.noreply.github.com> | 2021-07-22 21:51:38 -0400 |
| commit | b3bf0d4ebbee188b2979f985eeb93478a5945b31 (patch) | |
| tree | 2a861de6f5be92cbed1542f115a99e646a1793c9 /src/video_core/buffer_cache | |
| parent | 45c91da36980462c5f55596ba80286084ffd9db8 (diff) | |
vk_graphics_pipeline: Use VK_KHR_push_descriptor when available
~51% faster on Nvidia compared to previous method.
Diffstat (limited to 'src/video_core/buffer_cache')
0 files changed, 0 insertions, 0 deletions
